@@ -21,8 +21,8 @@ from itertools import chain
 from typing import Iterable, List, Optional, Tuple, Union, Dict
 
 import cachetools
-import numpy
 import pandas as pd
+import numpy as np
 from cachetools import TTLCache
 
 from gs_quant.api.data import DataApi
@@ -159,6 +159,7 @@ class QueryType(Enum):
     RETAIL_SELL_PCT_NOTIONAL = 'impliedRetailSellPctNotional'
     RETAIL_SELL_PCT_SHARES = 'impliedRetailSellPctShares'
     RETAIL_SELL_SHARES = 'impliedRetailSellShares'
+    FWD_POINTS = 'Fwd Points'
 
 
 class GsDataApi(DataApi):
@@ -244,7 +245,8 @@ class GsDataApi(DataApi):
             limit: int = None,
             offset: int = None,
             fields: List[str] = None,
-            include_history: bool = False
+            include_history: bool = False,
+            **kwargs
     ) -> List[dict]:
         params = {
             'limit': limit or 4000,
@@ -260,6 +262,7 @@ class GsDataApi(DataApi):
         if include_history:
             params['includeHistory'] = 'true'
 
+        params = {**params, **kwargs}
         body = GsSession.current._get(f'/data/{dataset_id}/coverage', payload=params)
         results = scroll_results = body['results']
         total_results = body['totalResults']
@@ -302,6 +305,14 @@ class GsDataApi(DataApi):
         result = GsSession.current._post('/data/{}'.format(dataset_id), payload=data, request_headers=headers)
         return result
 
+    @classmethod
+    def delete_data(cls, dataset_id: str, delete_query: Dict) -> Dict:
+        """
+        Delete data from dataset. You must have admin access to the dataset to delete data.
+        All data deleted is not recoverable.
+        """
+        return GsSession.current._delete(f'/data/{dataset_id}', payload=delete_query, use_body=True)
+
     @classmethod
     def get_definition(cls, dataset_id: str) -> DataSetEntity:
         definition = cls.__definitions.get(dataset_id)
@@ -474,7 +485,7 @@ class GsDataApi(DataApi):
         return providers
 
     @classmethod
-    def get_market_data(cls, query, request_id=None) -> pd.DataFrame:
+    def get_market_data(cls, query, request_id=None, ignore_errors: bool = False) -> pd.DataFrame:
         GsSession.current: GsSession
         start = time.perf_counter()
         try:
@@ -491,7 +502,11 @@ class GsDataApi(DataApi):
             container = e['queryResponse'][0]
             ids.extend(container.get('dataSetIds', ()))
             if 'errorMessages' in container:
-                raise MqValueError(f"measure service request {body['requestId']} failed: {container['errorMessages']}")
+                msg = f'measure service request {body["requestId"]} failed: {container["errorMessages"]}'
+                if ignore_errors:
+                    log_warning(request_id, _logger, msg)
+                else:
+                    raise MqValueError(msg)
             if 'response' in container:
                 df = MarketDataResponseFrame(container['response']['data'])
                 df.set_index('date' if 'date' in df.columns else 'time', inplace=True)
@@ -762,7 +777,7 @@ class GsDataApi(DataApi):
             for field_name, type_name in dataset_types.items():
                 if df.get(field_name) is not None and type_name in ('date', 'date-time') and \
                         len(df.get(field_name).value_counts()) > 0:
-                    df = df.astype({field_name: numpy.datetime64})
+                    df = df.astype({field_name: np.datetime64})
 
             field_names = dataset_types.keys()
 
