@@ -70,7 +70,13 @@ class FactorRiskUnit(Enum):
     Notional = 'Notional'
 
 
+class AttributionAggregationType(Enum):
+    Arithmetic = 'arithmetic'
+    Geometric = 'geometric'
+
+
 class ReportJobFuture:
+    """Report job future that monitors report status and results"""
     def __init__(self,
                  report_id: str,
                  job_id: str,
@@ -123,7 +129,7 @@ class ReportJobFuture:
 
 
 class Report:
-    """"Private variables"""
+    """General report class"""
 
     def __init__(self,
                  report_id: str = None,
@@ -252,6 +258,7 @@ class Report:
         GsReportApi.delete_report(self.id)
 
     def set_position_source(self, entity_id: str):
+        """ Set position source type and position source ID """
         is_portfolio = entity_id.startswith('MP')
         self.position_source_type = 'Portfolio' if is_portfolio else 'Asset'
         self.position_source_id = entity_id
@@ -261,6 +268,7 @@ class Report:
             self.type = ReportType.Portfolio_Thematic_Analytics if is_portfolio else ReportType.Asset_Thematic_Analytics
 
     def get_most_recent_job(self):
+        """ Retrieve the most current report job """
         jobs = GsReportApi.get_report_jobs(self.id)
         most_current_job = sorted(jobs, key=lambda i: i['createdTime'], reverse=True)[0]
         return ReportJobFuture(report_id=self.id,
@@ -275,6 +283,13 @@ class Report:
                  start_date: dt.date = None,
                  end_date: dt.date = None,
                  backcast: bool = None):
+        """
+        Schedule a report with the given date range
+
+        :param start_date: start date (optional)
+        :param end_date: end date (optional)
+        :param backcast: set to true if the report should be backcasted
+        """
         if None in [self.id, self.__position_source_id]:
             raise MqValueError('Can only schedule reports with valid IDs and Position Source IDs.')
         if self.position_source_type != PositionSourceType.Portfolio and None in [start_date, end_date]:
@@ -296,8 +311,16 @@ class Report:
     def run(self,
             start_date: dt.date = None,
             end_date: dt.date = None,
-            backcast: bool = None,
+            backcast: bool = False,
             is_async: bool = True):
+        """
+        Run a report with the given date range
+
+        :param start_date: start date (optional)
+        :param end_date: end date (optional)
+        :param backcast: set to true if the report should be backcasted; defaults to false
+        :param is_async: return immediately (true) or wait for results (false); defaults to true
+        """
         self.schedule(start_date, end_date, backcast)
         counter = 5
         while counter > 0:
@@ -325,6 +348,9 @@ class Report:
 
 
 class PerformanceReport(Report):
+    """
+    Historical analyses on measures like PnL and exposure of a position source over a date range
+    """
 
     def __init__(self,
                  report_id: str = None,
@@ -338,6 +364,27 @@ class PerformanceReport(Report):
                  status: Union[str, ReportStatus] = ReportStatus.new,
                  percentage_complete: float = None,
                  **kwargs):
+        """
+        Historical analyses on measures like PnL and exposure of a portfolio over a date range
+
+        :param report_id: Marquee report ID
+        :param name: report name
+        :param position_source_id: position source ID
+        :param position_source_type: position source (i.e. 'Portfolio', 'Asset', or 'Hedge')
+        :param parameters: parameters of the report
+        :param earliest_start_date: start date of report
+        :param latest_end_date: end date of report
+        :param latest_execution_time: date of the latest execution
+        :param status: status of of report (i.e. 'ready', 'executing', or 'done')
+        :param percentage_complete: percent of the report that is complete
+
+        **Examples**
+
+        >>> performance_report = PerformanceReport(
+        >>>     position_source_type=PositionSourceType.Portfolio,
+        >>>     position_source_id='PORTFOLIOID'
+        >>> )
+        """
         super().__init__(report_id, name, position_source_id, position_source_type,
                          ReportType.Portfolio_Performance_Analytics, parameters, earliest_start_date, latest_end_date,
                          latest_execution_time, status, percentage_complete)
@@ -348,6 +395,7 @@ class PerformanceReport(Report):
             **kwargs):
         """
         Get a performance report from the unique report identifier
+
         :param report_id: Marquee report ID
         :return: returns a PerformanceReport object that correlates to the Marquee report
         """
@@ -375,6 +423,7 @@ class PerformanceReport(Report):
                 end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio PnL
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -386,6 +435,7 @@ class PerformanceReport(Report):
                           end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio long exposure
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -397,6 +447,7 @@ class PerformanceReport(Report):
                            end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio short exposure
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -408,6 +459,7 @@ class PerformanceReport(Report):
                         end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio asset count
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -419,6 +471,7 @@ class PerformanceReport(Report):
                      end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio turnover
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -430,6 +483,7 @@ class PerformanceReport(Report):
                              end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio long asset count
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -442,6 +496,7 @@ class PerformanceReport(Report):
             -> Union[MDAPIDataBatchResponse, DataQueryResponse, tuple, list]:
         """
         Get historical portfolio short asset count
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -453,6 +508,7 @@ class PerformanceReport(Report):
                          end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio net exposure
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -464,6 +520,7 @@ class PerformanceReport(Report):
                            end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio gross exposure
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -475,6 +532,7 @@ class PerformanceReport(Report):
                         end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio trading PnL
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -486,6 +544,7 @@ class PerformanceReport(Report):
                              end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio trading cost PnL
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -497,6 +556,7 @@ class PerformanceReport(Report):
                                     end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio servicing cost long PnL
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -508,6 +568,7 @@ class PerformanceReport(Report):
                                      end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio servicing cost short PnL
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -519,6 +580,7 @@ class PerformanceReport(Report):
                                end_date: dt.date = None) -> pd.DataFrame:
         """
         Get historical portfolio asset count priced
+
         :param start_date: start date
         :param end_date: end date
         :return: returns a Pandas DataFrame with the results
@@ -530,6 +592,14 @@ class PerformanceReport(Report):
                     start_date: dt.date = None,
                     end_date: dt.date = None,
                     return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """
+        Get historical portfolio metrics
+
+        :param field: the entity property to be returned
+        :param start_date: start date
+        :param end_date: end date
+        :return: returns a Pandas DataFrame with the results
+        """
         fields = (field,)
         where = {'reportId': self.id}
         query = DataQuery(where=where, fields=fields, start_date=start_date, end_date=end_date)
@@ -543,6 +613,7 @@ class PerformanceReport(Report):
                           return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
         """
         Get many historical portfolio metrics
+
         :param measures: a list of metrics
         :param start_date: start date
         :param end_date: end date
@@ -563,6 +634,7 @@ class PerformanceReport(Report):
                                    return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
         """
         Get historical portfolio constituents
+
         :param fields: list of fields to include in the results
         :param start_date: start date
         :param end_date: end date
@@ -582,8 +654,57 @@ class PerformanceReport(Report):
         results = sum(results, [])
         return pd.DataFrame(results) if return_format == ReturnFormat.DATA_FRAME else results
 
+    def get_brinson_attribution(self,
+                                benchmark: str = None,
+                                currency: Currency = None,
+                                include_interaction: bool = False,
+                                aggregation_type: AttributionAggregationType = AttributionAggregationType.Arithmetic,
+                                start_date: dt.date = None,
+                                end_date: dt.date = None,
+                                return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """
+        Get PnL analytics called Brinson Attribution
+
+        :param benchmark: benchmark's unique Marquee identifier
+        :param currency: currency of results; if none passed results default to your portfolio's currency
+        :param include_interaction: show interaction independent of security selection
+        :param aggregation_type: either artihmetic or geometric
+        :param start_date: start date
+        :param end_date: end date
+        :param return_format: return format; defaults to a Pandas DataFrame, but can be manually
+        set to ReturnFormat.JSON
+        :return: Portfolio Brinson Attribution data for the requested date range
+
+        **Examples**
+
+        >>> brinson_attribution_results = performance_report.get_brinson_attribution (
+        >>>     benchmark=asset.get_marquee_id(),
+        >>>     include_interaction=True,
+        >>>     start_date=performance_report.earliest_start_date,
+        >>>     end_date=performance_report.latest_end_date,
+        >>> )
+        >>> display(pd.DataFrame(brinson_attribution_results))
+        """
+        results = GsReportApi.get_brinson_attribution_results(portfolio_id=self.position_source_id,
+                                                              benchmark=benchmark,
+                                                              currency=currency,
+                                                              include_interaction=include_interaction,
+                                                              aggregation_type=aggregation_type.value,
+                                                              start_date=start_date,
+                                                              end_date=end_date)
+        if return_format == ReturnFormat.DATA_FRAME:
+            rows = results.get('results')
+            rows_data_frame = pd.DataFrame(rows)
+            rows_data_frame.rename(columns=lambda c: titleize(c), inplace=True)
+            return rows_data_frame
+        return results
+
 
 class FactorRiskReport(Report):
+    """
+    Historical analyses on both the risk and attribution of a portfolio or asset to various factors determined by the
+    specified risk model
+    """
 
     def __init__(self,
                  risk_model_id: str = None,
@@ -600,6 +721,34 @@ class FactorRiskReport(Report):
                  status: Union[str, ReportStatus] = ReportStatus.new,
                  percentage_complete: float = None,
                  **kwargs):
+        """
+        Historical analyses on both the risk and attribution of a portfolio or asset to various factors determined by
+        the specified risk model
+
+        :param risk_model_id: risk model ID
+        :param fx_hedged: if position source is FX hedged
+        :param benchmark_id: optional benchmark asset ID to include in results
+        :param report_id: Marquee report ID
+        :param name: report name
+        :param position_source_id: position source ID
+        :param position_source_type: position source (i.e. 'Portfolio', 'Asset', or 'Hedge')
+        :param report_type: report type (i.e. 'Asset Factor Risk' or 'Portfolio Factor Risk')
+        :param earliest_start_date: start date of report
+        :param latest_end_date: end date of report
+        :param latest_execution_time: date of the latest execution
+        :param status: status of of report (i.e. 'ready', 'executing', or 'done')
+        :param percentage_complete: percent of the report that is complete
+
+        **Examples**
+
+        >>> risk_report = FactorRiskReport(
+        >>>     risk_model_id='RISKMODELID',
+        >>>     fx_hedged=True,
+        >>>     benchmark_id=benchmark.get_marquee_id(),
+        >>>     position_source_id='PORTFOLIOID',
+        >>>     position_source_type=PositionSourceType.Portfolio
+        >>> )
+        """
         super().__init__(report_id, name, position_source_id, position_source_type,
                          report_type, ReportParameters(risk_model=risk_model_id,
                                                        fx_hedged=fx_hedged,
@@ -611,9 +760,10 @@ class FactorRiskReport(Report):
             report_id: str,
             **kwargs):
         """
-        Get a performance report from the unique report identifier
+        Get a factor risk report from the unique report identifier
+
         :param report_id: Marquee report ID
-        :return: returns a PerfomanceReport object that correlates to the Marquee report
+        :return: returns a FactorRiskReport object that correlates to the Marquee report
         """
         return cls.from_target(GsReportApi.get_report(report_id))
 
@@ -657,6 +807,7 @@ class FactorRiskReport(Report):
                     unit: FactorRiskUnit = FactorRiskUnit.Notional) -> Union[Dict, pd.DataFrame]:
         """
         Get the raw results associated with the factor risk report
+
         :param mode: results mode; defaults to the portfolio level
         :param factors: optional list of factors; defaults to all of them
         :param factor_categories: optional list of factor categories; defaults to all of them
@@ -667,6 +818,15 @@ class FactorRiskReport(Report):
         set to ReturnFormat.JSON
         :param: unit: return the results in terms of notional or percent (defaults to notional)
         :return: risk report results
+
+        **Examples**
+
+        >>> factor_and_total_results = risk_report.get_results(
+        >>>     factors=['Factor', 'Specific'],
+        >>>     start_date=dt.date(2022, 1, 1),
+        >>>     end_date=dt.date(2021, 1, 1)
+        >>> )
+        >>> print(factor_and_total_results)
         """
         results = GsReportApi.get_factor_risk_report_results(risk_report_id=self.id,
                                                              view=mode.value,
@@ -688,6 +848,7 @@ class FactorRiskReport(Report):
                  unit: FactorRiskUnit = FactorRiskUnit.Notional) -> Dict:
         """
         Get the results associated with the factor risk report as seen on the Marquee user interface
+
         :param mode: views mode
         :param factor: optional factor name
         :param factor_category: optional factor category
@@ -696,6 +857,24 @@ class FactorRiskReport(Report):
         :param currency: currency
         :param: unit: return the results in terms of notional or percent (defaults to notional)
         :return: risk report results
+
+        **Examples**
+
+        >>> category_table = risk_report.get_view(
+        >>>     mode=FactorRiskViewsMode.Risk,
+        >>>     start_date=risk_report.latest_end_date,
+        >>>     end_date=risk_report.latest_end_date,
+        >>>     unit=FactorRiskUnit.Notional
+        >>> ).get('factorCategoriesTable')
+        >>> category_df = pd.DataFrame(category_table).filter(items=[
+        >>>     'name',
+        >>>     'proportionOfRisk',
+        >>>     'marginalContributionToRiskPercent',
+        >>>     'relativeMarginalContributionToRisk',
+        >>>     'exposure',
+        >>>     'avgProportionOfRisk'
+        >>> ])
+        >>> display(category_df)
         """
         return GsReportApi.get_factor_risk_report_view(
             risk_report_id=self.id,
@@ -709,20 +888,50 @@ class FactorRiskReport(Report):
         )
 
     def get_table(self,
-                  mode: FactorRiskTableMode = None,
+                  mode: FactorRiskTableMode,
                   factors: List[str] = None,
                   factor_categories: List[str] = None,
                   date: dt.date = None,
+                  start_date: dt.date = None,
+                  end_date: dt.date = None,
+                  unit: FactorRiskUnit = None,
                   currency: Currency = None,
                   order_by_column: str = None,
                   order_type: OrderType = None,
                   return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """
+        Get the results associated with the factor risk report formatted for the asset level table on the interface
+
+        :param mode: tables mode
+        :param factors: optional list of factors to filter by; defaults to all
+        :param factor_categories: optional list of factor categories to filter by; defaults to all
+        :param date: date for modes requiring snapshot data (defaults to the latest available date)
+        :param start_date: start date for modes requiring date range (defaults to 1 month before the end date)
+        :param end_date: end date for modes requiring date range (defaults to the latest available date)
+        :param unit: return the results in terms of notional or percent (defaults to notional)
+        :param currency: currency
+        :param order_by_column: column to order the rows by (defaults to name)
+        :param order_type: order ascending or descending (defaults to ascending)
+        :return: risk report table at asset level
+
+        **Examples**
+
+        >>> pnl_table = risk_report.get_table(
+        >>>     mode=FactorRiskTableMode.Pnl,
+        >>>     start_date=risk_report.earliest_start_date,
+        >>>     end_date=risk_report.latest_end_date
+        >>> )
+        >>> display(pd.DataFrame(pnl_table))
+        """
         table = GsReportApi.get_factor_risk_report_table(risk_report_id=self.id,
                                                          mode=mode,
                                                          factors=factors,
                                                          factor_categories=factor_categories,
+                                                         unit=unit.value if unit else None,
                                                          currency=currency,
                                                          date=date,
+                                                         start_date=start_date,
+                                                         end_date=end_date,
                                                          order_by_column=order_by_column,
                                                          order_type=order_type)
         if return_format == ReturnFormat.DATA_FRAME:
@@ -739,6 +948,7 @@ class FactorRiskReport(Report):
         return table
 
     def get_factor_pnl(self,
+                       mode: FactorRiskResultsMode = FactorRiskResultsMode.Portfolio,
                        factor_names: List[str] = None,
                        factor_categories: List[str] = None,
                        start_date: dt.date = None,
@@ -747,6 +957,8 @@ class FactorRiskReport(Report):
                        unit: FactorRiskUnit = FactorRiskUnit.Notional) -> pd.DataFrame:
         """
         Get historical factor PnL
+
+        :param mode: results mode; defaults to the portfolio level
         :param factor_names: optional list of factor names; defaults to all of them
         :param factor_categories: optional list of factor categories; defaults to all of them
         :param start_date: start date
@@ -755,7 +967,8 @@ class FactorRiskReport(Report):
         :param: unit: return the results in terms of notional or percent (defaults to notional)
         :return: a Pandas DataFrame with the results
         """
-        factor_data = self.get_results(factors=factor_names,
+        factor_data = self.get_results(mode=mode,
+                                       factors=factor_names,
                                        factor_categories=factor_categories,
                                        start_date=start_date,
                                        end_date=end_date,
@@ -766,6 +979,7 @@ class FactorRiskReport(Report):
         return _format_multiple_factor_table(factor_data, 'pnl')
 
     def get_factor_exposure(self,
+                            mode: FactorRiskResultsMode = FactorRiskResultsMode.Portfolio,
                             factor_names: List[str] = None,
                             factor_categories: List[str] = None,
                             start_date: dt.date = None,
@@ -774,6 +988,8 @@ class FactorRiskReport(Report):
                             unit: FactorRiskUnit = FactorRiskUnit.Notional) -> pd.DataFrame:
         """
         Get historical factor exposure
+
+        :param mode: results mode; defaults to the portfolio level
         :param factor_names: optional list of factor names; defaults to all of them
         :param factor_categories: optional list of factor categories; defaults to all of them
         :param start_date: start date
@@ -782,7 +998,8 @@ class FactorRiskReport(Report):
         :param: unit: return the results in terms of notional or percent (defaults to notional)
         :return: a Pandas DataFrame with the results
         """
-        factor_data = self.get_results(factors=factor_names,
+        factor_data = self.get_results(mode=mode,
+                                       factors=factor_names,
                                        factor_categories=factor_categories,
                                        start_date=start_date,
                                        end_date=end_date,
@@ -799,6 +1016,7 @@ class FactorRiskReport(Report):
                                       currency: Currency = None) -> pd.DataFrame:
         """
         Get historical factor proportion of risk
+
         :param factor_names: optional list of factor names; defaults to all of them
         :param factor_categories: optional list of factor categories; defaults to all of them
         :param start_date: start date
@@ -821,6 +1039,7 @@ class FactorRiskReport(Report):
                         currency: Currency = None) -> pd.DataFrame:
         """
         Get historical annual risk
+
         :param factor_names: optional list of factor names; must be from the following: "Factor", "Specific", "Total
         :param start_date: start date
         :param end_date: end date
@@ -841,6 +1060,7 @@ class FactorRiskReport(Report):
                        currency: Currency = None) -> pd.DataFrame:
         """
         Get historical daily risk
+
         :param factor_names: optional list of factor names; must be from the following: "Factor", "Specific", "Total
         :param start_date: start date
         :param end_date: end date
@@ -872,6 +1092,9 @@ def _format_multiple_factor_table(factor_data: List[Dict],
 
 
 class ThematicReport(Report):
+    """
+    Historical analyses on the exposure of a portfolio to various GS Flagship Thematic baskets over a date range
+    """
 
     def __init__(self,
                  report_id: str = None,
@@ -886,6 +1109,30 @@ class ThematicReport(Report):
                  status: Union[str, ReportStatus] = ReportStatus.new,
                  percentage_complete: float = None,
                  **kwargs):
+        """
+        Historical analyses on the exposure of a portfolio to various GS Flagship Thematic baskets over a date range
+
+        :param report_id: Marquee report ID
+        :param name: report name
+        :param position_source_id: position source ID
+        :param parameters: parameters of the report
+        :param position_source_type: position source (i.e. 'Portfolio', 'Asset', or 'Hedge')
+        :param report_type: report type (i.e. 'Portfolio Thematic Analytics' or 'Asset Thematic Analytics')
+        :param earliest_start_date: start date of report
+        :param latest_end_date: end date of report
+        :param latest_execution_time: date of the latest execution
+        :param status: status of of report (i.e. 'ready', 'executing', or 'done')
+        :param percentage_complete: percent of the report that is complete
+
+        **Examples**
+
+        >>> thematic_report = ThematicReport(
+        >>>     report_id='REPORTID',
+        >>>     position_source_type=PositionSourceType.Portfolio,
+        >>>     position_source_id='PORTFOLIOID',
+        >>>     parameters=None
+        >>> )
+        """
         super().__init__(report_id, name, position_source_id, position_source_type,
                          report_type, parameters, earliest_start_date, latest_end_date,
                          latest_execution_time, status, percentage_complete)
@@ -896,6 +1143,7 @@ class ThematicReport(Report):
             **kwargs):
         """
         Get a thematic report from the unique report identifier
+
         :param report_id: Marquee report ID
         :return: returns a ThematicReport object that correlates to the Marquee report
         """
@@ -924,6 +1172,7 @@ class ThematicReport(Report):
                           basket_ids: List[str] = None) -> pd.DataFrame:
         """
         Get all results from the thematic report for a date range
+
         :param start_date: start date
         :param end_date: end date
         :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
@@ -942,6 +1191,7 @@ class ThematicReport(Report):
                               basket_ids: List[str] = None) -> pd.DataFrame:
         """
         Get portfolio historical exposure to GS Flagship Thematic baskets
+
         :param start_date: start date
         :param end_date: end date
         :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
@@ -955,6 +1205,7 @@ class ThematicReport(Report):
                            basket_ids: List[str] = None) -> pd.DataFrame:
         """
         Get portfolio historical beta to GS Flagship Thematic baskets
+
         :param start_date: start date
         :param end_date: end date
         :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
@@ -988,6 +1239,15 @@ class ThematicReport(Report):
                                    end_date: dt.date = None,
                                    basket_ids: List[str] = None,
                                    regions: List[Region] = None) -> pd.DataFrame:
+        """
+        Get all portfolio thematic analytics for GS Flagshop Thematic baskets
+
+        :param start_date: start date
+        :param end_date: end date
+        :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
+        :param regions: regions by which to filter flagship thematic baskets; defaults to all regions
+        :return: a Pandas DataFrame with results
+        """
         results = GsThematicApi.get_thematics(entity_id=self.position_source_id,
                                               start_date=start_date,
                                               end_date=end_date,
@@ -1001,6 +1261,15 @@ class ThematicReport(Report):
                                         end_date: dt.date = None,
                                         basket_ids: List[str] = None,
                                         regions: List[Region] = None) -> pd.DataFrame:
+        """
+        Get portfolio thematic analytics for the five GS Flagship Thematic baskets with the highest thematic exposures
+
+        :param start_date: start date
+        :param end_date: end date
+        :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
+        :param regions: regions by which to filter flagship thematic baskets; defaults to all regions
+        :return: a Pandas DataFrame with the top 5 results
+        """
         results = GsThematicApi.get_thematics(entity_id=self.position_source_id,
                                               start_date=start_date,
                                               end_date=end_date,
@@ -1014,6 +1283,15 @@ class ThematicReport(Report):
                                            end_date: dt.date = None,
                                            basket_ids: List[str] = None,
                                            regions: List[Region] = None) -> pd.DataFrame:
+        """
+        Get portfolio thematic analytics for the five GS Flagship Thematic baskets with the lowest thematic exposures
+
+        :param start_date: start date
+        :param end_date: end date
+        :param basket_ids: optional list of thematic basket IDs to include; defaults to all of them
+        :param regions: regions by which to filter flagship thematic baskets; defaults to all regions
+        :return: a Pandas DataFrame with the bottom 5 results
+        """
         results = GsThematicApi.get_thematics(entity_id=self.position_source_id,
                                               start_date=start_date,
                                               end_date=end_date,
@@ -1028,6 +1306,7 @@ class ThematicReport(Report):
         """
         Get a by-asset breakdown of a portfolio or basket's thematic exposure to a particular flagship basket on a
         particular date
+
         :param date: date
         :param basket_id: GS flagship basket's unique Marquee ID
         :return: a Pandas DataFrame with results
@@ -1038,6 +1317,15 @@ class ThematicReport(Report):
 def get_thematic_breakdown_as_df(entity_id: str,
                                  date: dt.date,
                                  basket_id: str) -> pd.DataFrame:
+    """
+    Get a by-asset breakdown of a portfolio or basket's thematic exposure to a particular flagship basket on a
+    particular data and return as a Pandas DataFrame
+
+    :param entity_id: position source ID; i.e. portfolio or basket
+    :param date: date
+    :param basket_id: GS flagship basket's unique Marquee ID
+    :return: a Pandas DataFrame with results
+    """
     results = GsThematicApi.get_thematics(entity_id=entity_id,
                                           start_date=date,
                                           end_date=date,
@@ -1055,6 +1343,12 @@ def get_thematic_breakdown_as_df(entity_id: str,
 
 
 def flatten_results_into_df(results: List):
+    """
+    Flatten a list of thematic data into a Pandas DataFrame
+
+    :param results: a list of thematic data by date
+    :return: Pandas DataFrame with all results formatted
+    """
     all_results = []
     for result in results:
         date = result['date']
