@@ -28,6 +28,8 @@ from gs_quant.common import RiskMeasure
 from gs_quant.config import DisplayOptions
 from gs_quant.risk import DataFrameWithInfo, ErrorValue, FloatWithInfo, SeriesWithInfo, ResultInfo, \
     ScalarWithInfo, aggregate_results
+from gs_quant.risk.transform import Transformer
+from more_itertools import unique_everseen
 
 _logger = logging.getLogger(__name__)
 
@@ -133,27 +135,25 @@ def _value_for_date(result: Union[DataFrameWithInfo, SeriesWithInfo], date: Unio
         key.scenario,
         key.risk_measure)
 
-    if isinstance(raw_value, ErrorValue):
-        return raw_value
-    elif isinstance(raw_value, DataFrameWithInfo):
-        raw_df = raw_value.raw_value.set_index('dates')
-        return DataFrameWithInfo(
-            raw_df.reset_index(drop=True) if isinstance(date, dt.date) else raw_df,
-            risk_key=risk_key,
-            unit=result.unit,
-            error=result.error)
-    elif isinstance(raw_value, SeriesWithInfo):
-        return SeriesWithInfo(
-            raw_value.raw_value,
-            risk_key=risk_key,
-            unit=result.unit,
-            error=result.error)
+    unit = result.unit
+    error = result.error
+    if isinstance(raw_value, DataFrameWithInfo):
+        raw_value = raw_value.raw_value.set_index('dates')
+        raw_value = raw_value.reset_index(drop=True) if isinstance(date, dt.date) else raw_value
+    elif isinstance(raw_value, float):
+        unit = result.unit.get(date, result.unit) if unit else None
+    return _get_value_with_info(raw_value, risk_key, unit, error)
+
+
+def _get_value_with_info(value, risk_key, unit, error):
+    if isinstance(value, ErrorValue):
+        return value
+    elif isinstance(value, pd.DataFrame):
+        return DataFrameWithInfo(value, risk_key=risk_key, unit=unit, error=error)
+    elif isinstance(value, pd.Series):
+        return SeriesWithInfo(value.raw_value, risk_key=risk_key, unit=unit, error=error)
     else:
-        return FloatWithInfo(
-            risk_key,
-            raw_value,
-            unit=result.unit.get(date, result.unit) if result.unit else None,
-            error=result.error)
+        return FloatWithInfo(risk_key, value, unit=unit, error=error)
 
 
 def _risk_keys_compatible(lhs, rhs) -> bool:
@@ -275,10 +275,12 @@ class MultipleRiskMeasureResult(dict):
             if all(isinstance(v, (DataFrameWithInfo, SeriesWithInfo)) for v in self.values()):
                 return MultipleRiskMeasureResult(self.__instrument, ((k, _value_for_date(v, item))
                                                                      for k, v in self.items()))
+            elif all(isinstance(v, MultipleScenarioResult) for v in self.values()):
+                return MultipleRiskMeasureResult(self.__instrument, ((k, v[item]) for k, v in self.items()))
             else:
                 raise ValueError('Can only index by date on historical results')
         elif is_instance_or_iterable(item, Scenario):
-            if all(isinstance(v, (MultipleScenarioResult)) for v in self.values()):
+            if all(isinstance(v, MultipleScenarioResult) for v in self.values()):
                 return MultipleRiskMeasureResult(self.__instrument, ((k, _value_for_measure_or_scen(v, item))
                                                                      for k, v in self.items()))
             else:
@@ -334,7 +336,7 @@ class MultipleRiskMeasureResult(dict):
     def __op(self, operator, operand):
         values = {}
         for key, value in self.items():
-            if isinstance(value, pd.DataFrame):
+            if isinstance(value, pd.DataFrame) or isinstance(value, pd.Series):
                 new_value = value.copy()
                 new_value.value = operator(value.value, operand)
             else:
@@ -365,7 +367,7 @@ class MultipleRiskMeasureResult(dict):
                 return tuple(value.scenarios)
         return tuple()
 
-    def to_frame(self, values='default', index='default', columns='default', aggfunc=pd.unique,
+    def to_frame(self, values='default', index='default', columns='default', aggfunc=sum,
                  display_options: DisplayOptions = None):
         df = pd.DataFrame.from_records(self._to_records({}, display_options=display_options))
         if values is None and index is None and columns is None:
@@ -409,10 +411,24 @@ class MultipleRiskMeasureFuture(CompositeResultFuture):
         return self.__measures_to_futures
 
 
+class MultipleScenarioFuture(CompositeResultFuture):
+    def __init__(self, instrument: InstrumentBase, scenarios: Iterable[Scenario], futures: Iterable[PricingFuture]):
+        self.__instrument = instrument
+        self.__scenarios = scenarios
+        super().__init__(futures)
+
+    def _set_result(self):
+        res = next(iter(self.futures)).result()
+        values = tuple(res[res['label'] == r]['value'] for r in
+                       tuple(unique_everseen(res['label'].values))) if res.index.name == 'date' else tuple(
+            v for v in res['value'])
+        val_w_info = tuple(_get_value_with_info(v, res.risk_key, res.unit, res.error) for v in values)
+        self.set_result(MultipleScenarioResult(self.__instrument, {k: v for k, v in zip(self.__scenarios, val_w_info)}))
+
+
 class MultipleScenarioResult(dict):
     def __init__(self, instrument, dict_values: Iterable):
         super().__init__(dict_values)
-        self.__scenarios = self.keys()
         self.__instrument = instrument
 
     def __getitem__(self, item):
@@ -424,7 +440,7 @@ class MultipleScenarioResult(dict):
                 raise ValueError('Can only index by date on historical results')
         return super().__getitem__(item)
 
-    def to_frame(self, values='default', index='default', columns='default', aggfunc=pd.unique,
+    def to_frame(self, values='default', index='default', columns='default', aggfunc=sum,
                  display_options: DisplayOptions = None):
         df = pd.DataFrame.from_records(self._to_records({}, display_options=display_options))
         if values is None and index is None and columns is None:
@@ -446,7 +462,7 @@ class MultipleScenarioResult(dict):
 
     @property
     def scenarios(self):
-        return self.__scenarios
+        return self.keys()
 
     def _to_records(self, extra_dict, display_options: DisplayOptions = None):
         return list(chain.from_iterable(
@@ -467,9 +483,6 @@ class HistoricalPricingFuture(CompositeResultFuture):
             if isinstance(base, MultipleRiskMeasureResult):
                 result = MultipleRiskMeasureResult(base.instrument,
                                                    {k: base[k].compose(r[k] for r in results) for k in base.keys()})
-            elif isinstance(base, MultipleScenarioResult):
-                result = MultipleScenarioResult(base.instrument,
-                                                {k: base[k].compose(r[k] for r in results) for k in base.keys()})
             else:
                 result = base.compose(results)
             self.set_result(result)
@@ -571,13 +584,15 @@ class PortfolioRiskResult(CompositeResultFuture):
             else:
                 for idx, priceable in enumerate(self.portfolio):
                     result = self.__result(PortfolioPath(idx))
-                    if isinstance(result, (MultipleRiskMeasureResult, PortfolioRiskResult)):
+                    if isinstance(result, PortfolioRiskResult):
                         futures.append(result[item])
+                    elif isinstance(result, MultipleRiskMeasureResult):
+                        futures.append(MultipleRiskMeasureFuture(priceable, {
+                            k: PricingFuture(_value_for_measure_or_scen(result[k], item)) for k in result}))
                     elif isinstance(result, MultipleScenarioResult):
-                        # scenario = tuple(item) if isinstance(item, Iterable) else (item,)
                         futures.append(PricingFuture(_value_for_measure_or_scen(result, item)))
-
                 return PortfolioRiskResult(self.__portfolio, self.risk_measures, futures)
+
         elif is_instance_or_iterable(item, dt.date):
             for idx, _ in enumerate(self.portfolio):
                 result = self.__result(PortfolioPath(idx))
@@ -738,6 +753,21 @@ class PortfolioRiskResult(CompositeResultFuture):
         sub_portfolio = self.__portfolio.subset(paths, name=name)
         return PortfolioRiskResult(sub_portfolio, self.risk_measures, [p(self.futures) for p in paths])
 
+    def transform(self, risk_transformation: Transformer = None):
+        if risk_transformation is None:
+            return self
+        elif len(self.__risk_measures) > 1:
+            return MultipleRiskMeasureResult(self.portfolio,
+                                             ((r, self[r].transform(risk_transformation)) for r in
+                                              self.__risk_measures))
+        elif len(self.__risk_measures) == 1:
+            transformed_future = PricingFuture()
+            transformed_future.set_result(risk_transformation.apply(self.__results()))
+            transformed_future.done()
+            return PortfolioRiskResult(self.portfolio, self.risk_measures, (transformed_future,))
+        else:
+            return self
+
     def aggregate(self, allow_mismatch_risk_keys=False) -> Union[float, pd.DataFrame, pd.Series,
                                                                  MultipleRiskMeasureResult]:
         if len(self.__risk_measures) > 1:
