@@ -54,6 +54,20 @@ def api_mock_data() -> APIBacktestResult:
     return GsBacktestApi.backtest_result_from_response(pnl_response)
 
 
+def api_mock_data_portfolio() -> APIBacktestResult:
+    pnl_response = {
+        'RiskData': {
+            'PNL': [
+                {'date': '2019-02-18', 'value': 0},
+                {'date': '2019-02-19', 'value': -0.45793},
+                {'date': '2019-02-20', 'value': -0.36584}
+            ]
+        }
+    }
+
+    return GsBacktestApi.backtest_result_from_response(pnl_response)
+
+
 def mock_api_response(mocker, mock_result: APIBacktestResult):
     mocker.return_value = mock_result
 
@@ -459,6 +473,153 @@ def test_engine_mapping_listed(mocker):
     mocker.assert_called_with(backtest, None)
 
 
+@mock.patch.object(GsBacktestApi, 'run_backtest')
+def test_engine_mapping_market_model(mocker):
+    # 1. setup strategy
+
+    start_date = dt.date(2019, 2, 18)
+    end_date = dt.date(2019, 2, 20)
+
+    option = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Call,
+                      option_style=OptionStyle.European)
+
+    long_call = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Call,
+                         option_style=OptionStyle.European, buy_sell=BuySell.Buy)
+    short_put = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Put,
+                         option_style=OptionStyle.European, buy_sell=BuySell.Sell)
+
+    hedge_portfolio = Portfolio(name='SynFwd', priceables=[long_call, short_put])
+
+    action = EnterPositionQuantityScaledAction(priceables=option, trade_duration='1m')
+    trigger = PeriodicTrigger(
+        trigger_requirements=PeriodicTriggerRequirements(start_date=start_date, end_date=end_date, frequency='1m'),
+        actions=action)
+    hedgetrigger = PeriodicTrigger(
+        trigger_requirements=PeriodicTriggerRequirements(start_date=start_date, end_date=end_date, frequency='1b'),
+        actions=HedgeAction(EqDelta, priceables=hedge_portfolio, trade_duration='1b'))
+    strategy = Strategy(initial_portfolio=None, triggers=[trigger, hedgetrigger])
+
+    # 2. setup mock api response
+
+    mock_api_response(mocker, api_mock_data())
+
+    # 3. when run backtest
+
+    set_session()
+    EquityVolEngine.run_backtest(strategy, start_date, end_date, market_model=EquityMarketModel.SVR)
+
+    # 4. assert response
+
+    backtest_parameter_args = {
+        'trading_parameters': BacktestTradingParameters(
+            quantity=1,
+            quantity_type=BacktestTradingQuantityType.quantity.value,
+            trade_in_method=TradeInMethod.FixedRoll.value,
+            roll_frequency='1m'),
+        'underliers': [BacktestStrategyUnderlier(
+            instrument=option,
+            notional_percentage=100,
+            hedge=BacktestStrategyUnderlierHedge(risk_details=DeltaHedgeParameters(frequency='Daily')),
+            market_model=EquityMarketModel.SVR,
+            expiry_date_mode='otc')
+        ],
+        'index_initial_value': 0.0,
+        "measures": [FlowVolBacktestMeasure.ALL_MEASURES]
+    }
+    backtest_parameters = VolatilityFlowBacktestParameters.from_dict(backtest_parameter_args)
+
+    backtest = Backtest(name="Flow Vol Backtest",
+                        mq_symbol="Flow Vol Backtest",
+                        parameters=backtest_parameters,
+                        start_date=start_date,
+                        end_date=end_date,
+                        type='Volatility Flow',
+                        asset_class=AssetClass.Equity,
+                        currency=Currency.USD,
+                        cost_netting=False)
+
+    mocker.assert_called_with(backtest, None)
+
+
+@mock.patch.object(GsBacktestApi, 'run_backtest')
+def test_engine_mapping_portfolio(mocker):
+    # 1. setup strategy
+
+    start_date = dt.date(2019, 2, 18)
+    end_date = dt.date(2019, 2, 20)
+
+    call = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Call,
+                    option_style=OptionStyle.European)
+
+    put = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Put,
+                   option_style=OptionStyle.European)
+
+    portfolio = Portfolio(name='portfolio', priceables=[call, put])
+
+    long_call = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Call,
+                         option_style=OptionStyle.European, buy_sell=BuySell.Buy)
+    short_put = EqOption('.STOXX50E', expiration_date='3m', strike_price='ATM', option_type=OptionType.Put,
+                         option_style=OptionStyle.European, buy_sell=BuySell.Sell)
+
+    hedge_portfolio = Portfolio(name='SynFwd', priceables=[long_call, short_put])
+
+    action = EnterPositionQuantityScaledAction(priceables=portfolio, trade_duration='1m')
+    trigger = PeriodicTrigger(
+        trigger_requirements=PeriodicTriggerRequirements(start_date=start_date, end_date=end_date, frequency='1m'),
+        actions=action)
+    hedgetrigger = PeriodicTrigger(
+        trigger_requirements=PeriodicTriggerRequirements(start_date=start_date, end_date=end_date, frequency='1b'),
+        actions=HedgeAction(EqDelta, priceables=hedge_portfolio, trade_duration='1b'))
+    strategy = Strategy(initial_portfolio=None, triggers=[trigger, hedgetrigger])
+
+    # 2. setup mock api response
+
+    mock_api_response(mocker, api_mock_data_portfolio())
+
+    # 3. when run backtest
+
+    set_session()
+    EquityVolEngine.run_backtest(strategy, start_date, end_date)
+
+    # 4. assert response
+
+    backtest_parameter_args = {
+        'trading_parameters': BacktestTradingParameters(
+            quantity=1,
+            quantity_type=BacktestTradingQuantityType.quantity.value,
+            trade_in_method=TradeInMethod.FixedRoll.value,
+            roll_frequency='1m'),
+        'underliers': [BacktestStrategyUnderlier(
+            instrument=call,
+            notional_percentage=100,
+            hedge=BacktestStrategyUnderlierHedge(risk_details=DeltaHedgeParameters(frequency='Daily')),
+            market_model=EquityMarketModel.SFK,
+            expiry_date_mode='otc'),
+            BacktestStrategyUnderlier(
+                instrument=put,
+                notional_percentage=100,
+                hedge=BacktestStrategyUnderlierHedge(risk_details=DeltaHedgeParameters(frequency='Daily')),
+                market_model=EquityMarketModel.SFK,
+                expiry_date_mode='otc')
+        ],
+        'index_initial_value': 0.0,
+        "measures": [FlowVolBacktestMeasure.ALL_MEASURES]
+    }
+    backtest_parameters = VolatilityFlowBacktestParameters.from_dict(backtest_parameter_args)
+
+    backtest = Backtest(name="Flow Vol Backtest",
+                        mq_symbol="Flow Vol Backtest",
+                        parameters=backtest_parameters,
+                        start_date=start_date,
+                        end_date=end_date,
+                        type='Volatility Flow',
+                        asset_class=AssetClass.Equity,
+                        currency=Currency.USD,
+                        cost_netting=False)
+
+    mocker.assert_called_with(backtest, None)
+
+
 def test_supports_strategy():
     # 1. Valid strategy
 
