@@ -18,6 +18,7 @@ import datetime
 
 import pytest
 
+from gs_quant.base import EnumBase
 from gs_quant.markets.securities import *
 from gs_quant.session import *
 
@@ -216,6 +217,8 @@ class AssetContext:
 
 
 def test_get_security(mocker):
+    mocker.patch.object(GsSession, 'default_value', return_value=GsSession.get(Environment.QA, 'client_id', 'secret'))
+
     mock_response = {
         "results": [
             {
